package com.ruoyi.project.zjsgfa.mapper;

import java.util.List;
import com.ruoyi.project.zjsgfa.domain.SjSggyGjsbxnyq;

/**
 * 设计-施工概要-关键设备性能要求Mapper接口
 * 
 * @author ruoyi
 * @date 2025-08-18
 */
public interface SjSggyGjsbxnyqMapper 
{
    /**
     * 查询设计-施工概要-关键设备性能要求
     * 
     * @param id 设计-施工概要-关键设备性能要求主键
     * @return 设计-施工概要-关键设备性能要求
     */
    public SjSggyGjsbxnyq selectSjSggyGjsbxnyqById(Long id);

    /**
     * 查询设计-施工概要-关键设备性能要求列表
     * 
     * @param sjSggyGjsbxnyq 设计-施工概要-关键设备性能要求
     * @return 设计-施工概要-关键设备性能要求集合
     */
    public List<SjSggyGjsbxnyq> selectSjSggyGjsbxnyqList(SjSggyGjsbxnyq sjSggyGjsbxnyq);

    /**
     * 新增设计-施工概要-关键设备性能要求
     * 
     * @param sjSggyGjsbxnyq 设计-施工概要-关键设备性能要求
     * @return 结果
     */
    public int insertSjSggyGjsbxnyq(SjSggyGjsbxnyq sjSggyGjsbxnyq);

    /**
     * 修改设计-施工概要-关键设备性能要求
     * 
     * @param sjSggyGjsbxnyq 设计-施工概要-关键设备性能要求
     * @return 结果
     */
    public int updateSjSggyGjsbxnyq(SjSggyGjsbxnyq sjSggyGjsbxnyq);

    /**
     * 删除设计-施工概要-关键设备性能要求
     * 
     * @param id 设计-施工概要-关键设备性能要求主键
     * @return 结果
     */
    public int deleteSjSggyGjsbxnyqById(Long id);

    /**
     * 批量删除设计-施工概要-关键设备性能要求
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSjSggyGjsbxnyqByIds(Long[] ids);
}
